package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.SysScenic;

/**
 * 景区Service接口
 * 
 * @author haotian
 * @date 2024-11-08
 */
public interface ISysScenicService 
{
    /**
     * 查询景区
     * 
     * @param scenicId 景区主键
     * @return 景区
     */
    public SysScenic selectSysScenicByScenicId(Long scenicId);

    /**
     * 查询景区列表
     * 
     * @param sysScenic 景区
     * @return 景区集合
     */
    public List<SysScenic> selectSysScenicList(SysScenic sysScenic);

    /**
     * 新增景区
     * 
     * @param sysScenic 景区
     * @return 结果
     */
    public int insertSysScenic(SysScenic sysScenic);

    /**
     * 修改景区
     * 
     * @param sysScenic 景区
     * @return 结果
     */
    public int updateSysScenic(SysScenic sysScenic);

    /**
     * 批量删除景区
     * 
     * @param scenicIds 需要删除的景区主键集合
     * @return 结果
     */
    public int deleteSysScenicByScenicIds(Long[] scenicIds);

    /**
     * 删除景区信息
     * 
     * @param scenicId 景区主键
     * @return 结果
     */
    public int deleteSysScenicByScenicId(Long scenicId);
}
